@@ -23,7 +23,8 @@
 
 #include <QDBusInterface>
 #include <QObject>
-#include <QProcess>
+
+#include <libupower-glib/upower.h>
 
 class Battery : public QObject
 {
@@ -31,17 +32,37 @@ class Battery : public QObject
     Q_PROPERTY( bool powerdRunning
                 READ powerdRunning
                 CONSTANT)
-    
+
+    Q_PROPERTY( QString deviceString
+                READ deviceString
+                CONSTANT)
+
+    Q_PROPERTY( int lastFullCharge
+                READ lastFullCharge
+                NOTIFY lastFullChargeChanged)
+
 public:
     explicit Battery(QObject *parent = 0);
     ~Battery();
-    bool powerdRunning();
+    bool powerdRunning() const;
+    QString deviceString() const;
+    int lastFullCharge() const;
+    Q_INVOKABLE QVariantList getHistory(const QString &deviceString, const int timespan, const int resolution);
+
+Q_SIGNALS:
+    void lastFullChargeChanged();
 
 private:
     QDBusConnection m_systemBusConnection;
     QString m_objectPath;
     QDBusInterface m_powerdIface;
     bool m_powerdRunning;
+    UpDevice *m_device;
+    QString m_deviceString;
+    int m_lastFullCharge = 0;
+    void buildDeviceString();
+    void getLastFullCharge();
+    bool updateLastFullCharge(UpHistoryItem *item, int offset);
 };
 
 #endif // BATTERY_H
