@@ -18,6 +18,7 @@
 
 #include "plugin.h"
 #include "securityprivacy.h"
+#include "trust-store-model.h"
 
 #include <QtQml/QtQml>
 
@@ -25,6 +26,7 @@ void BackendPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("Ubuntu.SystemSettings.SecurityPrivacy"));
     qmlRegisterType<SecurityPrivacy>(uri, 1, 0, "UbuntuSecurityPrivacyPanel");
+    qmlRegisterType<TrustStoreModel>(uri, 1, 0, "TrustStoreModel");
 }
 
 void BackendPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
