@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 Canonical Ltd
+ * Copyright (C) 2013-2014 Canonical Ltd
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3 as
@@ -18,17 +18,33 @@
  *
 */
 
+#include "plugin.h"
+
 #include <QtQml>
 #include <QtQml/QQmlContext>
-#include "plugin.h"
+#include "update_manager.h"
+#include "system_update.h"
 #include "update.h"
+#include "download_tracker.h"
 
+using namespace UpdatePlugin;
+
+
+static QObject *qml_update_manager(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(engine)
+    Q_UNUSED(scriptEngine)
+    return new UpdateManager();
+}
 
 void BackendPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("Ubuntu.SystemSettings.Update"));
     
-    qmlRegisterType<Update>(uri, 1, 0, "UbuntuUpdatePanel");
+    qmlRegisterSingletonType<UpdateManager>(uri, 1, 0, "UpdateManager", qml_update_manager);
+    qmlRegisterType<SystemUpdate>(uri, 1, 0, "SystemUpdate");
+    qmlRegisterType<Update>(uri, 1, 0, "Update");
+    qmlRegisterType<DownloadTracker>(uri, 1, 0, "DownloadTracker");
 }
 
 void BackendPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
