@@ -15,11 +15,18 @@ public:
     explicit FakeSsoService(QObject *parent = 0);
 
     void getCredentials();
+
+    void setValidCredentials(bool value) { m_validCredentials = value; }
+    void setDeletedCredentials(bool value) { m_deletedCredentials = value; }
     
 signals:
     void credentialsFound(const Token&);
     void credentialsNotFound();
+    void credentialsDeleted();
 
+private:
+    bool m_validCredentials;
+    bool m_deletedCredentials;
 };
 
 }
